from setuptools import setup, find_packages

setup(
    name="3dlibrary",              # Paket adı
    version="0.1",
    packages=find_packages(),       # __init__.py olan tüm paketleri bulur
    install_requires=["Pillow"],    # PIL kütüphanesi gerekiyor
    author="Mehmet",
    description="Saf Python 3D kütüphanesi (OpenGL kullanmadan)",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/kullaniciadi/3dlibrary",  # opsiyonel
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
)
